==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/id/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Kolom Tambahan',
    'field'		                => 'Kolom',
    'about_fieldsets_title'		=> 'Tentang Set Kolom',
    'about_fieldsets_text'		=> 'Fieldsets memungkinkan Anda untuk membuat kolom tambahan yang seringkali dipakai untuk dapat digunakan pada model aset tertentu.',
    'custom_format'             => 'Format Tambahan...',
    'encrypt_field'      	        => 'Enkripsi nilai kolom ini di database',
    'encrypt_field_help'      => 'PERINGATAN: Mengenkripsi kolom menjadikan tidak bisa ditemukan.',
    'encrypted'      	        => 'Dienkripsi',
    'fieldset'      	        => 'Set Kolom',
    'qty_fields'      	      => 'Kolom Jumlah',
    'fieldsets'      	        => 'Kumpulan Set Kolom',
    'fieldset_name'           => 'Nama Kumpulan Set Kolom',
    'field_name'              => 'Nama Set Kolom',
    'field_values'            => 'Nilai Kolom',
    'field_values_help'       => 'Tambahkan opsi pilihan, satu opsi per baris. Baris kosong selain baris pertama akan diabaikan.',
    'field_element'           => 'Elemen Form',
    'field_element_short'     => 'Elemen',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format Ubahan',
    'field_custom_format_help'     => 'Kolom ini memungkinkan Anda menggunakan ekspresi regex untuk validasi. Ini harus dimulai dengan "regex:" - misalnya, untuk memvalidasi bahwa nilai kolom kustom berisi IMEI yang valid (15 angka numerik), Anda dapat menggunakan <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Harus diisi',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Digunakan oleh Model',
    'order'   		            => 'Urutan',
    'create_fieldset'         => 'Set Kolom Baru',
    'create_field'            => 'Tambah Kolom Ubahan',
    'value_encrypted'      	        => 'Nilai dari kolom ini di database dienkripsi. hanya pengguna admin yang bisa melihat nilai deskripsinya',
    'show_in_email'     => 'Sertakan nilai bidang ini dalam email checkout yang dikirim kepada pengguna? Bidang terenkripsi tidak dapat dimasukkan dalam email.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/id/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Kolom Tambahan',
    'manage'                    => 'Manage',
    'field'		                => 'Kolom',
    'about_fieldsets_title'		=> 'Tentang Set Kolom',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Enkripsi nilai kolom ini di database',
    'encrypt_field_help'      => 'PERINGATAN: Mengenkripsi kolom menjadikan tidak bisa ditemukan.',
    'encrypted'      	        => 'Dienkripsi',
    'fieldset'      	        => 'Set Kolom',
    'qty_fields'      	      => 'Kolom Jumlah',
    'fieldsets'      	        => 'Kumpulan Set Kolom',
    'fieldset_name'           => 'Nama Kumpulan Set Kolom',
    'field_name'              => 'Nama Set Kolom',
    'field_values'            => 'Nilai Kolom',
    'field_values_help'       => 'Tambahkan opsi pilihan, satu opsi per baris. Baris kosong selain baris pertama akan diabaikan.',
    'field_element'           => 'Elemen Form',
    'field_element_short'     => 'Elemen',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format Ubahan',
    'field_custom_format_help'     => 'Kolom ini memungkinkan Anda menggunakan ekspresi regex untuk validasi. Ini harus dimulai dengan "regex:" - misalnya, untuk memvalidasi bahwa nilai kolom kustom berisi IMEI yang valid (15 angka numerik), Anda dapat menggunakan <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Harus diisi',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Digunakan oleh Model',
    'order'   		            => 'Urutan',
    'create_fieldset'         => 'Set Kolom Baru',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Tambah Kolom Ubahan',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Nilai dari kolom ini di database dienkripsi. hanya pengguna admin yang bisa melihat nilai deskripsinya',
    'show_in_email'     => 'Sertakan nilai bidang ini dalam email checkout yang dikirim kepada pengguna? Bidang terenkripsi tidak dapat dimasukkan dalam email.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
